gatenlp.serialization.srsly API documentation
Description: For now, placeholder file for an implementation of a (de)serialization module based on https://github.com/explosion/srsly (for the formats supported …

# Module `gatenlp.serialization.srsly`

For now, placeholder file for an implementation of a (de)serialization module based on https://github.com/explosion/srsly (for the formats supported there only).

Expand source code

    """
    For now, placeholder file for an implementation of a (de)serialization module based on
    https://github.com/explosion/srsly (for the formats supported there only).
    """